/****************************************************************************
** Meta object code from reading C++ file 'printpreview.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../scribus-1.6.6/scribus/ui/printpreview.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'printpreview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_PrintPreview_t {
    QByteArrayData data[14];
    char stringdata0[178];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_PrintPreview_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_PrintPreview_t qt_meta_stringdata_PrintPreview = {
    {
QT_MOC_LITERAL(0, 0, 12), // "PrintPreview"
QT_MOC_LITERAL(1, 13, 7), // "doPrint"
QT_MOC_LITERAL(2, 21, 0), // ""
QT_MOC_LITERAL(3, 22, 10), // "jumpToPage"
QT_MOC_LITERAL(4, 33, 3), // "num"
QT_MOC_LITERAL(5, 37, 9), // "redisplay"
QT_MOC_LITERAL(6, 47, 10), // "toggleCMYK"
QT_MOC_LITERAL(7, 58, 17), // "toggleCMYK_Colour"
QT_MOC_LITERAL(8, 76, 19), // "toggleAllFromHeader"
QT_MOC_LITERAL(9, 96, 21), // "onPrintLanguageChange"
QT_MOC_LITERAL(10, 118, 27), // "onInkTableCellDoubleClicked"
QT_MOC_LITERAL(11, 146, 3), // "row"
QT_MOC_LITERAL(12, 150, 21), // "scaleBox_valueChanged"
QT_MOC_LITERAL(13, 172, 5) // "value"

    },
    "PrintPreview\0doPrint\0\0jumpToPage\0num\0"
    "redisplay\0toggleCMYK\0toggleCMYK_Colour\0"
    "toggleAllFromHeader\0onPrintLanguageChange\0"
    "onInkTableCellDoubleClicked\0row\0"
    "scaleBox_valueChanged\0value"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_PrintPreview[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       9,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   59,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    1,   60,    2, 0x0a /* Public */,
       5,    0,   63,    2, 0x0a /* Public */,
       6,    0,   64,    2, 0x0a /* Public */,
       7,    0,   65,    2, 0x0a /* Public */,
       8,    0,   66,    2, 0x0a /* Public */,
       9,    1,   67,    2, 0x09 /* Protected */,
      10,    1,   70,    2, 0x09 /* Protected */,
      12,    1,   73,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,    4,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,   11,
    QMetaType::Void, QMetaType::Int,   13,

       0        // eod
};

void PrintPreview::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<PrintPreview *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->doPrint(); break;
        case 1: _t->jumpToPage((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->redisplay(); break;
        case 3: _t->toggleCMYK(); break;
        case 4: _t->toggleCMYK_Colour(); break;
        case 5: _t->toggleAllFromHeader(); break;
        case 6: _t->onPrintLanguageChange((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 7: _t->onInkTableCellDoubleClicked((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 8: _t->scaleBox_valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (PrintPreview::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&PrintPreview::doPrint)) {
                *result = 0;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject PrintPreview::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_meta_stringdata_PrintPreview.data,
    qt_meta_data_PrintPreview,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *PrintPreview::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PrintPreview::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_PrintPreview.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int PrintPreview::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void PrintPreview::doPrint()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
